Reusable MCP runtime primitives for tool discovery, execution, and HTTP serving.
This crate contains the protocol-facing pieces that can be shared by multiple
higher-level projects. It intentionally avoids any dependency on cloudllm
so crates such as thoughtchain and cloudllm can both build on the same
MCP foundation without introducing circular dependencies.
Re-exports
pub use builder::MCPServerBuilder;pub use builder_utils::AuthConfig;pub use builder_utils::IpFilter;pub use client::McpClientProtocol;pub use events::McpEvent;pub use events::McpEventHandler;pub use http::HttpServerAdapter;pub use http::HttpServerConfig;pub use http::HttpServerInstance;pub use protocol::Tool;pub use protocol::ToolDefinition;pub use protocol::ToolError;pub use protocol::ToolMetadata;pub use protocol::ToolParameter;pub use protocol::ToolParameterType;pub use protocol::ToolProtocol;pub use protocol::ToolRegistry;pub use protocol::ToolResult;pub use resources::ResourceError;pub use resources::ResourceMetadata;pub use resources::ResourceProtocol;pub use server::UnifiedMcpServer;
Modules
- builder
- Generic builder for MCP-compatible HTTP tool servers.
- builder_
utils - Utilities for MCPServerBuilder
- client
- HTTP client protocol for talking to MCP-compatible legacy tool servers.
- events
- MCP-specific event types and observer trait.
- http
- HTTP Server Adapter for MCP
- protocol
- Tool protocol abstraction layer.
- resources
- Resource Protocol Abstraction
- server
- Unified MCP Server