MCPServerBuilder

Struct MCPServerBuilder 

pub struct MCPServerBuilder { /* private fields */ }
Builder for creating MCP-compatible HTTP servers with registered tools.

Implementations

Source

impl MCPServerBuilder

pub fn new() -> Self

Create a new empty builder using the default HTTP adapter.

pub async fn with_custom_tool( self, tool_name: &str, protocol: Arc<dyn ToolProtocol>, ) -> Self

Register a custom tool protocol under a tool name.

pub fn with_bearer_token(self, token: impl Into<String>) -> Self

Require bearer token authentication.

pub fn with_basic_auth( self, username: impl Into<String>, password: impl Into<String>, ) -> Self

Require basic authentication.

pub fn allow_ip(self, ip: &str) -> Result<Self, String>

Allow a specific IP address.

pub fn allow_cidr(self, cidr: &str) -> Result<Self, String>

Allow a CIDR block.

pub fn allow_localhost_only(self) -> Self

Restrict access to localhost only.

pub fn with_adapter(self, adapter: Arc<dyn HttpServerAdapter>) -> Self

Override the HTTP adapter.

pub fn with_event_handler(self, handler: Arc<dyn McpEventHandler>) -> Self

Attach an MCP event handler.

pub async fn start_on( self, port: u16, ) -> Result<HttpServerInstance, Box<dyn Error + Send + Sync>>

Start the server on the supplied port on localhost.

pub async fn start_at( self, addr: SocketAddr, ) -> Result<HttpServerInstance, Box<dyn Error + Send + Sync>>

Start the server at an explicit socket address.